Data I/O
=========

This module provides input/output utilities for loading and saving concept data.

.. currentmodule:: torch_concepts.data.io

Summary
-------

**I/O Functions and Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   extract_zip
   extract_tar
   save_pickle
   load_pickle
   download_url
   DownloadProgressBar


Function Documentation
----------------------

.. autofunction:: extract_zip

.. autofunction:: extract_tar

.. autofunction:: save_pickle

.. autofunction:: load_pickle

.. autofunction:: download_url


Class Documentation
-------------------

.. autoclass:: DownloadProgressBar
   :members:
   :undoc-members:
   :show-inheritance:
